#\!/bin/bash

# Colors
GREEN='\033[0;32m'
YELLOW='\033[1;33m'
RED='\033[0;31m'
NC='\033[0m' # No Color

# Function to get local IP address
get_ip_address() {
    local ip=""
    
    if command -v ip &> /dev/null; then
        ip=$(ip -4 addr show scope global | grep -oP '(?<=inet\s)\d+(\.\d+){3}' | head -n 1)
    elif command -v hostname &> /dev/null; then
        ip=$(hostname -I | awk '{print $1}')
    elif command -v ifconfig &> /dev/null; then
        ip=$(ifconfig | grep -Eo 'inet (addr:)?([0-9]*\.){3}[0-9]*' | grep -Eo '([0-9]*\.){3}[0-9]*' | grep -v '127.0.0.1' | head -n 1)
    fi
    
    echo "$ip"
}

# Get IP address
IP_ADDRESS=$(get_ip_address)

echo -e "${GREEN}Starting Transmission RSS Manager...${NC}"
echo -e "${GREEN}The web interface will be available at:${NC}"
echo -e "${YELLOW}  http://localhost:5000${NC}"
echo -e "${YELLOW}  http://$IP_ADDRESS:5000${NC}"
echo -e "${YELLOW}Press Ctrl+C to stop the application${NC}"

# Create logs directory if it doesn't exist
mkdir -p logs

# Run the application
./TransmissionRssManager --urls=http://0.0.0.0:5000

# If we got here, check if there was an error
if [ $? -ne 0 ]; then
    echo -e "${RED}The application exited with an error.${NC}"
    echo -e "${YELLOW}Check the logs directory for more information.${NC}"
    exit 1
fi
