using System;
using System.Collections.Generic;
using System.Linq;
using System.Linq.Expressions;
using System.Threading.Tasks;

namespace TransmissionRssManager.Data.Repositories
{
    public interface IRepository<T> where T : class
    {
        Task<IEnumerable<T>> GetAllAsync();
        
        Task<IEnumerable<T>> FindAsync(Expression<Func<T, bool>> predicate);
        
        Task<T?> GetByIdAsync(int id);
        
        Task<T?> FirstOrDefaultAsync(Expression<Func<T, bool>> predicate);
        
        Task AddAsync(T entity);
        
        Task AddRangeAsync(IEnumerable<T> entities);
        
        Task UpdateAsync(T entity);
        
        Task RemoveAsync(T entity);
        
        Task RemoveRangeAsync(IEnumerable<T> entities);
        
        Task<bool> AnyAsync(Expression<Func<T, bool>> predicate);
        
        Task<int> CountAsync(Expression<Func<T, bool>> predicate);
        
        Task SaveChangesAsync();
        
        IQueryable<T> Query();
    }
}