using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.EntityFrameworkCore;
using TransmissionRssManager.Data.Models;

namespace TransmissionRssManager.Data.Repositories
{
    public class TorrentRepository : Repository<Torrent>, ITorrentRepository
    {
        public TorrentRepository(TorrentManagerContext context) : base(context)
        {
        }
        
        public async Task<IEnumerable<Torrent>> GetCompletedNotProcessedAsync()
        {
            return await _dbSet
                .Where(t => t.PercentDone >= 1.0 && !t.PostProcessed)
                .ToListAsync();
        }
        
        public async Task<Torrent?> GetByHashAsync(string hash)
        {
            return await _dbSet
                .FirstOrDefaultAsync(t => t.Hash == hash);
        }
        
        public async Task<IEnumerable<Torrent>> GetRecentlyAddedAsync(int count)
        {
            return await _dbSet
                .OrderByDescending(t => t.AddedOn)
                .Take(count)
                .ToListAsync();
        }
        
        public async Task<IEnumerable<Torrent>> GetAllWithRssFeedItemsAsync()
        {
            return await _dbSet
                .Include(t => t.RssFeedItem)
                .ThenInclude(i => i!.RssFeed)
                .ToListAsync();
        }
    }
}